@@ -8,6 +8,9 @@ class Error(Exception):
 class InvalidTokenOrUser(Error):
     pass
 
+class InvalidVersion(Error):
+    pass
+
 class BunkResult:
     def __init__(self,method,image,raw,title=None,subreddit=None,author=None,id=None,upvote=None,downvote=None,comments=None,nsfw=None,created_at=None,score=None):
         self.method = method
@@ -24,6 +27,24 @@ class BunkResult:
             self.created_at = datetime.datetime.fromtimestamp(float(created_at))
         self.score = score
 
+class BunkWeather:
+    def __init__(self,location,country,last_updated,condition,img,temp_c,temp_f,wind_mph,wind_kph,wind_dir,humidity,feelslike_c,feelslike_f,raw):
+        self.location = location
+        self.country = country
+        self.last_updated = datetime.datetime.fromtimestamp(float(last_updated))
+        self.condition = condition
+        self.img = img
+        self.temp = {"Celsius": temp_c, "C": temp_c, "Farenheit": temp_f, "F": temp_f}
+        self.temp_c = temp_c
+        self.temp_f = temp_f
+        self.wind_mph = wind_mph
+        self.wind_kph = wind_kph
+        self.wind_dir = wind_dir
+        self.humidity = self.humidity
+        self.feelslike_c = feelslike_c
+        self.feelslike_f = feelslike_f
+        self.raw = raw
+
 class BunkAPI:
     def __init__(self,token,id,version=1):
         self.token = token
@@ -32,7 +53,15 @@ class BunkAPI:
         self.credits = 'Created and Maintained by DaWinnerIsHere#1264.'
 
     def donkey(self):
-        x = requests.get(f'https://bunkapi.xyz/api/v{self.version}/donkey/{self.id}?token={self.token}')
+        if self.version == 1:
+            x = requests.get(f'https://bunkapi.xyz/api/v1/donkey/{self.id}?token={self.token}')
+        elif self.version == 2:
+            headers = {
+            "token": self.token
+            }
+            x = requests.post(f'https://bunkapi.xyz/api/v2/donkey/{self.id}',headers=headers)
+        else:
+            raise InvalidVersion
         x = x.json()
         if x['status'] != 200:
             raise InvalidTokenOrUser
@@ -51,7 +80,15 @@ class BunkAPI:
             return BunkResult(method='donkey',title=title,subreddit=subreddit,author=author,image=image,id=id,upvote=upvote,downvote=downvote,comments=comments,nsfw=nsfw,created_at=created_at,score=score,raw=x)
 
     def meme(self):
-        x = requests.get(f'https://bunkapi.xyz/api/v{self.version}/meme/{self.id}?token={self.token}')
+        if self.version == 1:
+            x = requests.get(f'https://bunkapi.xyz/api/v1/meme/{self.id}?token={self.token}')
+        elif self.version == 2:
+            headers = {
+            "token": self.token
+            }
+            x = requests.post(f'https://bunkapi.xyz/api/v2/meme/{self.id}',headers=headers)
+        else:
+            raise InvalidVersion
         x = x.json()
         if x['status'] != 200:
             raise InvalidTokenOrUser
@@ -70,7 +107,7 @@ class BunkAPI:
             return BunkResult(method='meme',title=title,subreddit=subreddit,author=author,image=image,id=id,upvote=upvote,downvote=downvote,comments=comments,nsfw=nsfw,created_at=created_at,score=score,raw=x)
 
     def llama(self):
-        x = requests.get(f'https://bunkapi.xyz/api/v{self.version}/llama/{self.id}?token={self.token}')
+        x = requests.get(f'https://bunkapi.xyz/api/v1/donkey/{self.id}?token={self.token}')
         x = x.json()
         if x['status'] != 200:
             raise InvalidTokenOrUser
@@ -89,7 +126,15 @@ class BunkAPI:
             return BunkResult(method='llama',title=title,subreddit=subreddit,author=author,image=image,id=id,upvote=upvote,downvote=downvote,comments=comments,nsfw=nsfw,created_at=created_at,score=score,raw=x)
 
     def alpaca(self):
-        x = requests.get(f'https://bunkapi.xyz/api/v{self.version}/alpaca/{self.id}?token={self.token}')
+        if self.version == 1:
+            x = requests.get(f'https://bunkapi.xyz/api/v1/alpaca/{self.id}?token={self.token}')
+        elif self.version == 2:
+            headers = {
+            "token": self.token
+            }
+            x = requests.post(f'https://bunkapi.xyz/api/v2/alpaca/{self.id}',headers=headers)
+        else:
+            raise InvalidVersion
         x = x.json()
         if x['status'] != 200:
             raise InvalidTokenOrUser
@@ -146,7 +191,15 @@ class BunkAPI:
             return BunkResult(method='potato',title=title,subreddit=subreddit,author=author,image=image,id=id,upvote=upvote,downvote=downvote,comments=comments,nsfw=nsfw,created_at=created_at,score=score,raw=x)
 
     def aww(self):
-        x = requests.get(f'https://bunkapi.xyz/api/v{self.version}/aww/{self.id}?token={self.token}')
+        if self.version == 1:
+            x = requests.get(f'https://bunkapi.xyz/api/v1/aww/{self.id}?token={self.token}')
+        elif self.version == 2:
+            headers = {
+            "token": self.token
+            }
+            x = requests.post(f'https://bunkapi.xyz/api/v2/aww/{self.id}',headers=headers)
+        else:
+            raise InvalidVersion
         x = x.json()
         if x['status'] != 200:
             raise InvalidTokenOrUser
@@ -165,7 +218,15 @@ class BunkAPI:
             return BunkResult(method='aww',title=title,subreddit=subreddit,author=author,image=image,id=id,upvote=upvote,downvote=downvote,comments=comments,nsfw=nsfw,created_at=created_at,score=score,raw=x)
 
     def moose(self):
-        x = requests.get(f'https://bunkapi.xyz/api/v{self.version}/moose/{self.id}?token={self.token}')
+        if self.version == 1:
+            x = requests.get(f'https://bunkapi.xyz/api/v1/moose/{self.id}?token={self.token}')
+        elif self.version == 2:
+            headers = {
+            "token": self.token
+            }
+            x = requests.post(f'https://bunkapi.xyz/api/v2/moose/{self.id}',headers=headers)
+        else:
+            raise InvalidVersion
         x = x.json()
         if x['status'] != 200:
             raise InvalidTokenOrUser
@@ -203,7 +264,15 @@ class BunkAPI:
             return BunkResult(method='camel',title=title,subreddit=subreddit,author=author,image=image,id=id,upvote=upvote,downvote=downvote,comments=comments,nsfw=nsfw,created_at=created_at,score=score,raw=x)
 
     def seal(self):
-        x = requests.get(f'https://bunkapi.xyz/api/v{self.version}/seal/{self.id}?token={self.token}')
+        if self.version == 1:
+            x = requests.get(f'https://bunkapi.xyz/api/v1/seal/{self.id}?token={self.token}')
+        elif self.version == 2:
+            headers = {
+            "token": self.token
+            }
+            x = requests.post(f'https://bunkapi.xyz/api/v2/seal/{self.id}',headers=headers)
+        else:
+            raise InvalidVersion
         x = x.json()
         if x['status'] != 200:
             raise InvalidTokenOrUser
@@ -222,7 +291,15 @@ class BunkAPI:
             return BunkResult(method='seal',title=title,subreddit=subreddit,author=author,image=image,id=id,upvote=upvote,downvote=downvote,comments=comments,nsfw=nsfw,created_at=created_at,score=score,raw=x)
 
     def elephant(self):
-        x = requests.get(f'https://bunkapi.xyz/api/v{self.version}/elephant/{self.id}?token={self.token}')
+        if self.version == 1:
+            x = requests.get(f'https://bunkapi.xyz/api/v1/elephant/{self.id}?token={self.token}')
+        elif self.version == 2:
+            headers = {
+            "token": self.token
+            }
+            x = requests.post(f'https://bunkapi.xyz/api/v2/elephant/{self.id}',headers=headers)
+        else:
+            raise InvalidVersion
         x = x.json()
         if x['status'] != 200:
             raise InvalidTokenOrUser
@@ -260,7 +337,15 @@ class BunkAPI:
             return BunkResult(method='zebra',title=title,subreddit=subreddit,author=author,image=image,id=id,upvote=upvote,downvote=downvote,comments=comments,nsfw=nsfw,created_at=created_at,score=score,raw=x)
 
     def amongus(self):
-        x = requests.get(f'https://bunkapi.xyz/api/v{self.version}/amongus/{self.id}?token={self.token}')
+        if self.version == 1:
+            x = requests.get(f'https://bunkapi.xyz/api/v1/amongus/{self.id}?token={self.token}')
+        elif self.version == 2:
+            headers = {
+            "token": self.token
+            }
+            x = requests.post(f'https://bunkapi.xyz/api/v2/amongus/{self.id}',headers=headers)
+        else:
+            raise InvalidVersion
         x = x.json()
         if x['status'] != 200:
             raise InvalidTokenOrUser
@@ -304,3 +389,37 @@ class BunkAPI:
             raise InvalidTokenOrUser
         else:
             return x['data']
+
+    def shorten(self,url):
+        xdata = {"longUrl": url}
+        headers = {"token": self.token}
+        x = requests.post(f'https://bunkapi.xyz/api/v2/shorten/{self.id}',headers=headers,json=xdata)
+        x = x.json()
+        if x['status'] != 200:
+            raise InvalidTokenOrUser
+        else:
+            return x['data']['short']
+
+    def weather(self,city):
+        headers = {"token": self.token}
+        xdata = {"city": city}
+        x = requests.post(f'https://bunkapi.xyz/api/v2/weather/{self.id}',headers=headers,json=xdata)
+        x = x.json()
+        x = x.json()
+        if x['status'] != 200:
+            raise InvalidTokenOrUser
+        else:
+            location = x['data']['location']
+            country = x['data']['country']
+            last_updated = x['data']['last_updated']
+            condition = x['data']['condition']
+            img = x['data']['img']
+            temp_c = x['data']['temp_c']
+            temp_f = x['data']['temp_f']
+            wind_mph = x['data']['wind_mph']
+            wind_kph = x['data']['wind_kph']
+            wind_dir = x['data']['wind_dir']
+            humidity = x['data']['humidity']
+            feelslike_c = x['data']['feelslike_c']
+            feelslike_f = x['data']['feelslike_f']
+            return BunkWeather(location=location,country=country,last_updated=last_updated,condition=condition,img=img,temp_c=temp_c,temp_f=temp_f,wind_mph=wind_mph,wind_kph=wind_kph,wind_dir=wind_dir,humidity=humidity,feelslike_c=feelslike_c,feelslike_f=feelslike_f,raw=x)
